色，戒 (豆瓣)
Description: 色，戒电影简介和剧情介绍,色，戒影评、图片、预告片、影讯、论坛、在线购票
Keywords: 色，戒,色，戒,色，戒影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.169豆瓣电影Top250

# 色，戒 (2007)

导演: 李安
编剧: 王蕙玲 / 詹姆斯·夏慕斯 / 张爱玲
主演: 梁朝伟 / 汤唯 / 陈冲 / 王力宏 / 庹宗华 / 朱芷莹 / 高英轩 / 柯宇纶 / 阮德锵 / 钱嘉乐 / 苏岩 / 何赛飞 / 宋茹惠 / 樊光耀 / 卢燕 / 刘洁 / 余娅 / 王琳 / 王侃 / 竹下明子 / 阿努潘·凯尔
类型: 剧情 / 爱情 / 情色
制片国家/地区: 中国台湾 / 中国大陆 / 美国 / 中国香港
语言: 汉语普通话 / 上海话 / 英语 / 粤语 / 日语 / 印地语
上映日期: 2007-11-01(中国大陆) / 2007-09-24(中国台湾) / 2007-09-26(中国香港) / 2007-08-30(威尼斯电影节) / 2007-10-26(美国)
片长: 158分钟 / 145分钟(中国大陆)
又名: 色|戒 / 色·戒 / 色戒 / Lust, Caution
IMDb: tt0808357
豆瓣评分
引用
8.6
736007人评价
5星
45.5%
4星
41.3%
3星
12.1%
2星
0.8%
1星
0.3%
好于 99% 情色片
好于 98% 爱情片
想看 看过
评价:
推荐

## 色，戒的剧情简介 · · · · · ·

本是岭南大学学生的王佳芝（汤唯 饰）因战争辗转到了香港读书，她在香港大学加入了爱国青年邝裕民（王力宏 饰）组织的话剧组，他们主演的爱国话剧更激起了他们的爱国情操。当邝裕民得知汪伪政府的特务头子易先生（梁朝伟 饰）正在香港的时候，他们便密谋要刺杀易先生。化名“麦太太”的王佳芝很快得到了易太太（陈冲 饰）的信任与喜爱，同时美丽的“麦太太”也吸引了易先生的眼球，正当事情进行得如火如荼之际，易先生突然要回到上海去。
此后王佳芝一直生活在上海，没想到重遇了邝裕民。当得知刺杀行动还没结束时，王佳芝再次成为了特务，再次以“麦太太”的身份出现在易先生的面前。
重逢后的二人关系进一步发展，此时的易先生因爱上了王佳芝而对她毫无忌讳，王佳芝的内心也变得起伏不定。刺杀行动进行正顺利，但当易先生送给王佳芝璀璨钻戒表达爱意时，王佳芝做出了惊人的决定…… ©豆瓣

## 色，戒的演职员 · · · · · · ( 全部 55 )

- 李安 导演
- 梁朝伟 饰 易先生（易默成）
- 汤唯 饰 王佳芝 / 麦太太
- 陈冲 饰 易太太
- 王力宏 饰 邝裕民
- 庹宗华 饰 老吴

## 色，戒的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片1860 · 添加 )

## 色，戒的获奖情况 · · · · · · ( 全部 )

- 第64届威尼斯电影节
- 金狮奖
- 李安

- 第65届金球奖
- 电影类 最佳外语片(提名)

- 第44届台北金马影展
- 金马奖 最佳剧情片

## 喜欢这部电影的人也喜欢 · · · · · ·

  花样年华

  重庆森林

  罗马假日

  甜蜜蜜

  爱在黎明破晓前

  阿飞正传

  泰坦尼克号

  爱乐之城

  天使爱美丽

  傲慢与偏见

我要写短评

## 色，戒的短评 · · · · · · ( 全部 138735 条 )

热门 / 最新 / 好友

### 15176 有用 影志 看过 2007-11-06 22:51:01

男人是政治的动物，女人是情感的动物。李安用床戏“将易先生的内心活动外在化，外显他的恐惧、他的愤怒和挫折。你可以形容一个人如何不具备相信别人的能力，但更绝的是让他在高潮时都不敢闭上眼睛” “如果说断背山是一段发生在天堂里的爱情，那色戒就是来自地狱的爱情。”——李安

### 15955 有用 SheliaLiu 看过 2016-07-29 01:39:23

“第一次觉得李安可怕，是看《色戒》。觉得害怕，不是那十分钟的床戏，而是因为电影里彻头彻尾的虚无——爱情是荒谬的，友情是虚伪的，亲情是荒芜的，国家是四分五裂的，革命是似是而非的，革命者更是不可靠的……只有性爱的快乐是真实的，而这唯一的真实恰恰又是不可说的。”—摘录

### 7124 有用 江寒园 看过 2017-05-22 17:06:11

“快走”, 汤唯说完这句话转到梁朝伟特写, 梁表情数变（“表情数变”,这是我在看网络小说时经常吐槽的一个词，但没想到居然真的有人能够表现出来）从微笑,困惑, 到醒悟, 再到慌乱, 种种神情一闪而过, 梁朝伟在这里直接奉献出了影帝级别的表演。最后一幕, 妻子进来, 光落在梁脸上, 而眼中隐有泪光闪动…

### 6914 有用 月想花容 看过 2008-03-09 11:51:58

再看《色戒》觉得很残酷。王佳芝是因为爱上了邝裕民才加入了这个所谓的爱国计划。但这个口才甚好的爱国青年却不像他所标榜的那样勇敢。甚至连担起对心爱的女人在肉体上负责的能力都没有。而后她却发现易先生跟她想的确实不一样。易是个好情人嘛。至少她愿意为了他放弃这个计划。而这个计划的败露则意味着让她自己死。最后那些革命者面对死亡哭了。这个电影蕴涵的太多。很喜欢。

### 7773 有用 眠去 看过 2007-11-19 13:24:34

恍惚间，她相信他爱她。

> 更多短评 138735条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 色，戒的影评 · · · · · · ( 全部 4458 条 )

热门 / 最新 / 好友
艾小柯 2007-10-15 15:14:41

## 《色戒》中的三场床戏

前面王佳芝与梁润生的部分不提，单说后面极有层次感的三场床戏。 第一场虐爱。我记得以前读到过一篇描写男女情与性关系非常精彩的一段文字：“两个人要相逢，相吸，然后是眼角眉梢，你进我推，徘徊着，猜测着，试探着，多少的辛勤多少的准备，赤身肉搏，就为那欲生欲死的一瞬... (展开)
12922 611 803回应 收起
盒饭 2007-11-05 20:48:24

## 如果她叫王佳芝，如果他叫邝裕民

“王佳芝！”她在舞台中央，听到有人喊她，转过头，向二楼望去。那几张似笑非笑的面孔，是她的劫数，也是宿命。 在爱情上，多数人会主观为别人，客观为自己，一如爱本身就是自私的。一个人爱上另一个人，有时是希望通过爱找寻自己，有时是希望借助爱证明自己。 对她来说，爱从... (展开)
6879 257 405回应 收起
spanisheyes123 2007-11-18 23:36:06

## 张秘书、郭司机、阿妈和书房—开启《色戒》悬疑迷案的钥匙

这篇影评可能有剧透

博客: http://www.mtime.com/my/spanisheyes123/ "在天涯论坛，一位热情高涨的网友以《开启〈色·戒〉悬疑迷案的钥匙》为题，从悬疑角度对影片展开了详细的分析。在这篇长达6万字的连载帖子里，作者对多处台词、人物、情节、背景、道具、特写等进行了细致入微的描述，几乎如... (展开)
5964 299 805回应 收起
水木丁 2007-11-10 17:57:38

## 王佳芝介就一倒霉孩子！

这篇影评可能有剧透

我发现我这个人有点毛病，看电影之前不能看影评，因为看了就影响自己看电影，所以从来不看。但是这次我发现我毛病大了，看电影之后也不能看，看了一些乱七八糟的解读之后就会忍不住想写上几句，可见以后也不必看了，但是这次就算了，已经中了招了，就随便再说几句吧。 看《色... (展开)
3156 206 407回应 收起
艾小柯 2007-11-01 09:26:35

## 三看《色|戒》

本来不想把李安的电影《色|戒》与张爱玲的小说放到一起来评论，因为正如我在先前的影评中所述，电影已经是艺术加工上的艺术再加工，从政治的角度看它究竟有几分忠实于史实，有没有“正确”的刻画抗日革命者等等都是近乎荒谬可笑的评论方式。但这样的比较近来似乎有越演越烈的趋... (展开)
3329 215 233回应 收起
何日君回来 2018-12-14 01:01:31

## 解析《色戒》五场床戏。

这篇影评可能有剧透

本文首发公众号何日君回来，转载约稿请联系：hehua499。 第一场跟梁润生的床戏 先说邝裕民自己既然喜欢王佳芝（也知道王佳芝很可能喜欢自己），为什么王佳芝的初夜，他不要？活生生让给梁润生？ 这里不得不佩服李安的老辣，他挑了谁来演邝裕民？王力宏。 王力宏是个典型的什么... (展开)
4303 7 115回应 收起
非富贵不闲人 2007-09-28 01:31:34

## 张爱玲vs李安

李安到底是比张爱玲慈悲。 张爱玲的小说结尾，易先生处决王佳芝之后，是洋洋得意的。他与王佳芝是虎与伥，是最终极的占有，这才是张爱玲一贯的绝决与残酷。而片中，梁朝伟坐在空荡荡的床沿，满目泪水，他还是爱王佳芝的。李安貌似谨遵原著，其实做了本质上的改编。说到底李安... (展开)
1866 60 154回应 收起
veronique 2007-11-03 16:37:49

## 色戒——李安是坏人

猥琐的正义 多好的一个故事，多吊诡的一场无爱之欢，也只有张爱玲的笔写得。换作大陆常规的思路来拍，一定是我方英俊潇洒男战士潜入敌军内部，很快俘获敌军美艳女特务（通常还是某大官的女儿）的芳心，于是女特务弃暗投明协助男战士，最后男人不仅功德圆满，而且还陶陶然抱得... (展开)
1585 113 205回应 收起
pipihua 2007-10-17 20:18:39

## 好看也不好看的《色戒》－－完整版观后感

我是个俗人，没有拜读过张爱玲的原著，对文艺片也从不感兴趣。如果不是媒体炒得沸沸扬扬的床戏，我可能并不会看这样的片子，顶多也就是在家里看看盗版。就是为了一睹朝伟GG的蛋蛋的风采，周末，和朋友去香港看了这部即将下档的三级片――《色戒》。 不得不承认，这的... (展开)
867 91 138回应 收起
dancing dust 2007-11-17 22:50:39

## 色戒：天蝎女的华丽表演

终于去看了色戒，很精致的一部片子，节奏恰当，张力十足。 整部电影，好像就是一道论述题--- 王佳芝为什么在最后关头对易先生说那两个字 --“走吧”？ 当时身旁坐了两个唧唧喳喳的上海女人，看到王佳芝放走易先生的时候，忍不住叫起来：“格女宁哪能噶港啦？！” 李安对媒体... (展开)
860 43 127回应 收起

> 更多影评 4458篇

添加新讨论

## 讨论区 · · · · · ·

挺好看的呀，可 get √ | 来自南柯 | 31 回应 | 2022-11-23 23:45:52
一开始冒险在别墅门口杀了他不就？？？？ | 来自培风 | 16 回应 | 2022-11-23 12:33:52
为什么说王佳芝的同学和组织很虚伪？怎样对她才不... | 来自晴雨绿自如 | 6 回应 | 2022-11-23 10:04:29
很好奇，麻将桌上马太太和易先生怎么搭上经营的呢... | 来自豆友PoXSgjvcm0 | 4 回应 | 2022-11-23 09:54:17
如果王佳芝最后没有说“快走”的话易会被杀吗？！ | 来自momo | 11 回应 | 2022-11-23 09:17:57

> 去这部影片的讨论区（全部961条）

## 关于《色，戒》的问题 · · · · · · ( 全部61个 )

- 易先生对王佳芝究竟有没有感情？ 31人回答
- 王佳芝从珠宝店出来以后，留恋地看橱窗里的衣服，还有那快活的车夫是什么意思？ 13人回答

> 全部61个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 深情即是一桩悲剧，必得以死来句读。 (眠去)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 一禁成名 (影志)
- 【坚强的女性】 (影志)
- 你想要的 (影志)

## 谁在看这部电影 · · · · · ·

- 264726162
  2分钟前 看过
- LY
  3分钟前 想看
- 现在时间上午十
  4分钟前 看过

1139511人看过 / 250707人想看

订阅色，戒的评论:
feed: rss 2.0